aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJohanna Äijälä <johanna.aijala@qt.io>2022-06-23 13:49:46 +0300
committerJohanna Äijälä <johanna.aijala@qt.io>2022-10-14 15:16:41 +0300
commitc1fc588ae7b18841f8aa007604e9bf4e8f040125 (patch)
tree1a990a09f581e09b5fea5637b010e96f73414418
parent7776bb257770c2b78d02396659813ea928f4bb78 (diff)
Provisioning: update Squish 7.0.1
Update Squish to 7.0.1, include versions with Qt6.3 and 6.2 support. Change-Id: I2bd7cd51a41befdbf2ef242eb72c2c2add84f733 Reviewed-by: Heikki Halmet <heikki.halmet@qt.io> (cherry picked from commit 6754cb362a08cdb1a4a098bde9a6cde0f81c6c44) Reviewed-by: Qt Cherry-pick Bot <cherrypick_bot@qt-project.org>
-rwxr-xr-xcoin/provisioning/common/unix/squishInstall.sh36
-rw-r--r--coin/provisioning/common/windows/squishInstall.ps18
2 files changed, 22 insertions, 22 deletions
diff --git a/coin/provisioning/common/windows/squishInstall.ps1 b/coin/provisioning/common/windows/squishInstall.ps1
index 0159ec64..fcaf2249 100644
--- a/coin/provisioning/common/windows/squishInstall.ps1
+++ b/coin/provisioning/common/windows/squishInstall.ps1
@@ -42,12 +42,12 @@
# This script will pre-installed squish package for Windows.
# Squish is need by Release Test Automation (RTA)
-$version = "6.7.2"
-$qtBranch = "62x"
+$version = "7.0.1"
+$qtBranch = "63x"
$targetDir = "C:\Utils\squish"
$squishPackage = "C:\Utils\rta_squish"
$squishUrl = "\\ci-files01-hki.intra.qt.io\provisioning\squish\jenkins_build\stable"
-$licenseUrl = "\\ci-files01-hki.intra.qt.io\provisioning\squish\coin\"
+$licenseUrl = "\\ci-files01-hki.intra.qt.io\provisioning\squish\coin\$qtBranch"
# Squish license
$licensePackage = ".squish-license"
@@ -67,7 +67,7 @@ if (($OSVersion -eq "Windows 10 Enterprise") -or ($OSVersion -eq "Windows 10 Pro
# In Windows 11 case $OSVersion is 'Windows 10 Pro'
$winVersion = "win10"
if (Is64BitWinHost) {
- $sha1 = "3dd65fe3996bffd25892d5a7dfd2da26420a3f33"
+ $sha1 = "9c1554ba55f3d4927f89d0d939a52988272d5494"
}
} else {
$winVersion = "n/a"
diff --git a/coin/provisioning/common/unix/squishInstall.sh b/coin/provisioning/common/unix/squishInstall.sh
index 09b5e0f3..87b066b4 100755
--- a/coin/provisioning/common/unix/squishInstall.sh
+++ b/coin/provisioning/common/unix/squishInstall.sh
@@ -47,20 +47,20 @@ set -ex
# This script will fetch and extract pre-buildt squish package for Linux and Mac.
# Squish is need by Release Test Automation (RTA)
-version="6.7.2"
-qtBranch="62x"
+version="7.0.1"
+qtBranch="63x"
installFolder="/opt"
squishFolder="$installFolder/squish"
preBuildCacheUrl="ci-files01-hki.intra.qt.io:/hdd/www/input/squish/jenkins_build/stable"
licenseFile=".squish-license"
-licenseUrl="http://ci-files01-hki.intra.qt.io/input/squish/coin/$licenseFile"
-licenseSHA="bda9c3bce2b9a74cb10ead9e87a4ebacd9eef4c2"
+licenseUrl="http://ci-files01-hki.intra.qt.io/input/squish/coin/$qtBranch/$licenseFile"
+licenseSHA="e84b499a2011f9bb1a6eefc7b2338d7ae770927a"
if uname -a |grep -q Darwin; then
compressedFolder="prebuild-squish-$version-$qtBranch-mac.tar.gz"
- sha1="6b7d80be4d107ba53ac9218fe5ca79f72c6e1e2d"
+ sha1="ed8aa2e902808741fb9496a0d339d4c145530eef"
else
compressedFolder="prebuild-squish-$version-$qtBranch-linux64.tar.gz"
- sha1="1f57efd6f21a994b07f28b0b44ff7972bbf51733"
+ sha1="a9de35bba9b4dd9afabdde4df14564428745a979"
fi
mountFolder="/tmp/squish"
@@ -110,8 +110,8 @@ fi
if uname -a |grep -q "Ubuntu"; then
if [ ! -e "/usr/lib/tcl8.6" ]; then
sudo mkdir /usr/lib/tcl8.6
- #this needs to be copied only to squish_for_qt6
- sudo cp "$squishFolder/squish_for_qt6/tcl/lib/tcl8.6/init.tcl" /usr/lib/tcl8.6/
+ #this needs to be copied only to squish_for_qt62
+ sudo cp "$squishFolder/squish_for_qt62/tcl/lib/tcl8.6/init.tcl" /usr/lib/tcl8.6/
fi
fi
@@ -124,26 +124,26 @@ sudo chown qt:$usersGroup "$HOME/$licenseFile"
echo "Set commands for environment variables in .bashrc"
if uname -a |grep -q "Ubuntu"; then
- echo "export SQUISH_PATH=$squishFolder/squish_for_qt6" >> ~/.profile
- echo "export PATH=\$PATH:$squishFolder/squish_for_qt6/bin" >> ~/.profile
+ echo "export SQUISH_PATH=$squishFolder/squish_for_qt62" >> ~/.profile
+ echo "export PATH=\$PATH:$squishFolder/squish_for_qt62/bin" >> ~/.profile
else
- echo "export SQUISH_PATH=$squishFolder/squish_for_qt6" >> ~/.bashrc
- echo "export PATH=\$PATH:$squishFolder/squish_for_qt6/bin" >> ~/.bashrc
+ echo "export SQUISH_PATH=$squishFolder/squish_for_qt63" >> ~/.bashrc
+ echo "export PATH=\$PATH:$squishFolder/squish_for_qt63/bin" >> ~/.bashrc
fi
echo "Verifying Squish, available installations:"
ls -la $squishFolder
-if "$squishFolder/squish_for_qt5/bin/squishrunner" --testsuite "$squishFolder/suite_test_squish" | grep "Squish test run successfully" ; then
- echo "Squish for Qt5 installation tested successfully"
+if "$squishFolder/squish_for_qt62/bin/squishrunner" --testsuite "$squishFolder/suite_test_squish" | grep "Squish test run successfully" ; then
+ echo "Squish for Qt6.3 installation tested successfully"
else
- echo "Squish for Qt5 test failed! Package wasn't installed correctly."
+ echo "Squish for Qt6.3 test failed! Package wasn't installed correctly."
exit 1
fi
-if "$squishFolder/squish_for_qt6/bin/squishrunner" --testsuite "$squishFolder/suite_test_squish" | grep "Squish test run successfully" ; then
- echo "Squish for Qt6 installation tested successfully"
+if "$squishFolder/squish_for_qt63/bin/squishrunner" --testsuite "$squishFolder/suite_test_squish" | grep "Squish test run successfully" ; then
+ echo "Squish for Qt6.2 installation tested successfully"
else
- echo "Squish for Qt6 test failed! Package wasn't installed correctly."
+ echo "Squish for Qt6.2 test failed! Package wasn't installed correctly."
exit 1
fi